#!/bin/sh
#
# file:        test_empty_payload.sh
# description: Check that the ROHC library correctly compresses/decompresses
#              IP/ROHC packets with empty payloads
# author:      Didier Barvaux <didier@barvaux.org>
#
# This script may be used by creating a link "test_empty_payload_PACKET.sh"
# where:
#    PACKET  is the packet type to check for, it is used to choose the source
#            capture located in the 'inputs' subdirectory.
#
# Script arguments:
#    test_empty_payload_PACKET.sh [verbose]
# where:
#   verbose          prints the traces of test application
#

# skip test in case of cross-compilation
if [ "${CROSS_COMPILATION}" = "yes" ] && \
   [ -z "${CROSS_COMPILATION_EMULATOR}" ] ; then
	exit 77
fi

# parse arguments
SCRIPT="$0"
VERBOSE="$1"
VERY_VERBOSE="$2"
if [ "x$MAKELEVEL" != "x" ] ; then
	BASEDIR="${srcdir}"
	APP="./test_empty_payload${CROSS_COMPILATION_EXEEXT}"
else
	BASEDIR=$( dirname "${SCRIPT}" )
	APP="${BASEDIR}/test_empty_payload${CROSS_COMPILATION_EXEEXT}"
fi

# extract the packet type from the name of the script
CAPTURE_NAME=$( echo "${SCRIPT}" | \
                ${SED} -e 's#^.*/test_empty_payload_##' -e 's#\.sh$##' )
PACKET_TYPE=$( echo "${CAPTURE_NAME}" | ${AWK} -F'_' '{ print $1 }' )
PROFILE_NAME=$( echo "${CAPTURE_NAME}" | ${AWK} -F'_' '{ print $2 }' )
if [ -z "${PROFILE_NAME}" ] ; then
	PROFILE_NAME="auto"
fi
CAPTURE_SOURCE="${BASEDIR}/inputs/${CAPTURE_NAME}.pcap"

# check that capture exists
if [ ! -r "${CAPTURE_SOURCE}" ] ; then
	echo "source capture not found or not readable, please do not run $0 directly!"
	exit 1
fi

CMD="${CROSS_COMPILATION_EMULATOR} ${APP} ${CAPTURE_SOURCE} ${PROFILE_NAME} ${PACKET_TYPE}"

# source valgrind-related functions
. ${BASEDIR}/../../valgrind.sh

# run without valgrind in verbose mode or quiet mode
if [ "${VERBOSE}" = "verbose" ] ; then
	if [ "${VERY_VERBOSE}" = "verbose" ] ; then
		run_test_without_valgrind ${CMD} || exit $?
	else
		run_test_without_valgrind ${CMD} > /dev/null || exit $?
	fi
else
	run_test_without_valgrind ${CMD} > /dev/null 2>&1 || exit $?
fi

[ "${USE_VALGRIND}" != "yes" ] && exit 0

# run with valgrind in verbose mode or quiet mode
if [ "${VERBOSE}" = "verbose" ] ; then
	if [ "${VERY_VERBOSE}" = "verbose" ] ; then
		run_test_with_valgrind ${BASEDIR}/../../valgrind.xsl ${CMD} || exit $?
	else
		run_test_with_valgrind ${BASEDIR}/../../valgrind.xsl ${CMD} >/dev/null || exit $?
	fi
else
	run_test_with_valgrind ${BASEDIR}/../../valgrind.xsl ${CMD} > /dev/null 2>&1 || exit $?
fi

